/*
A copyright statement is attached to every file and product created for the
project.  It takes the form of the copyright statement for this 
document:

The project provides a modern way to design and knit garments
using domestic and semi-professional knitting machines.  This document
describes the LockController hardware.

Copyright (C) 2020 Owen Mace and Odile Lambert

This document is free information: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
*/
/*Yarn guide for an E6000 knitting machine.

Attachment module dimensions:
  ModuleLength  = 15.2; //X direction
  ModuleWidth   = 13.0; //Y direction
  ModuleHeight  = 28.0; //Z direction

All measurements are in mm
*/

$fn = 50;
Tolerance = 0.2;

//Torus
InnerDiameter = 10;
OuterDiameter = 18;
//Calculated
CircleRadius  = ( OuterDiameter - InnerDiameter) / 2;
//Arm
ArmLength = 110;
ArmWidth  = 5;
ArmHeight = CircleRadius * 2;

include </home/owen/Passap/3D Models/Yarn Mast Module/Yarn Mast Module.scad>
translate([ 0, ModuleWidth / 2, 0])
rotate([ 0, 0, 180])
  YarnMastAttachment();
//Add a block at end of mast attachment
translate([ -0.01, -ModuleWidth / 2, 0]) //-0.01 required for a 2-manifold
  cube([ 3, ModuleWidth, ModuleHeight]);
//Add two arms
translate([ 0, 2, ArmHeight / 2]) rotate([  0, 0, 30])
  Arm();
translate([ 0, -2, ArmHeight / 2]) rotate([  0, 0, -30])
  Arm();
//Add cross arm
translate([ ArmLength * cos( 30) - ArmWidth / 2,
           -ArmLength * sin( 30) + ArmWidth / 2 + CircleRadius,
            0])
  cube([ 5,
         2 * ArmLength * sin( 30) - InnerDiameter - CircleRadius,
         ArmHeight]);
//Arm module includes torus and gusset
module Arm()
{
  H = ModuleHeight - ArmHeight;
  difference()
  {
    union()
    {
      //Torus
      translate([ ArmLength, 0, 0])
      rotate_extrude(convexity = 10, $fn = 100)
      translate([ InnerDiameter / 2 + CircleRadius, 0, 0])
        circle( r = CircleRadius, $fn = 100);
      //Arm
      translate([ 0, -2.5, -ArmHeight / 2])
        cube([ ArmLength - InnerDiameter / 2 - CircleRadius,
               ArmWidth, ArmHeight]);
      //Gusset 
      translate([ 0, ArmWidth / 2, ArmHeight - 5]) rotate([ 90, 0, 0])
        linear_extrude( height = ArmWidth)
        {
          polygon( GussetPoints, paths = [ 0, 1, 2, 3], 10);
        }
        GussetPoints = [[ 0, 0], [ 2 * H, 0], [ 0, H], [ 0, 0]];
    }
    //Remove hole
    translate([ H / 1.5, 4, 6]) rotate([ 90, 0, 0])
      cylinder( h = ArmWidth * 2, r = 6);
  }
}
